@@ -31,7 +31,7 @@ class init_anim:
         self.frame_duration = t[-1]/speed_up*self.frame_rate
         """:type: `int`: number of total frames in animation"""
 
-        frame_interper = interp1d(np.linspace(0, t[-1]*1.00001, len(t), np.linspace(0, self.frame_duration, len(t)))
+        frame_interper = interp1d(np.linspace(0, t[-1]*1.00001, len(t), np.linspace(0, self.frame_duration, len(t))))
 
         self.frames = frame_interper(t).astype(int)
         """:type: `np.ndarray`: the frames that Blender will animate and have corresponding data for"""
